@@ -48,43 +48,55 @@ class StartPage(tk.Frame):
     def __init__(self, parent, controller):
         tk.Frame.__init__(self, parent)
         self.controller = controller
-        label = tk.Label(self, text="Welcome to ZebraZoom!", font=controller.title_font)
-        label.pack(side="top", fill="x", pady=10)
         
-        button0 = tk.Button(self, text="Prepare configuration file for tracking",
-                            command=lambda: controller.show_frame("ChooseVideoToCreateConfigFileFor"))
+        self.columnconfigure(0, weight=1)
+        self.columnconfigure(1, weight=1)
+        self.columnconfigure(2, weight=1)
         
-        button1 = tk.Button(self, text="Run ZebraZoom on a video",
-                            command=lambda: controller.show_frame("VideoToAnalyze"))
-               
-        button3 = tk.Button(self, text="Run ZebraZoom on several videos",
-                            command=lambda: controller.show_frame("SeveralVideos"))
+        # tk.Label(self, text="Welcome to ZebraZoom!", font=controller.title_font).pack()
         
-        button2 = tk.Button(self, text="Visualize ZebraZoom's output",
-                            command=lambda: controller.showResultsVisualization())
+        # tk.Label(self, text="1 - Configuration File Creation", pady=10).pack()
         
-        tk.Label(self, text="", font=controller.title_font).pack()
-        button0.pack()
-        tk.Label(self, text="", font=controller.title_font).pack()
-        button1.pack()
+        # tk.Button(self, text="Prepare configuration file for tracking", command=lambda: controller.show_frame("ChooseVideoToCreateConfigFileFor")).pack()
+        # tk.Label(self, text="You first need to create a configuration file for each 'type' of video you want to track.").pack(side=tk.RIGHT)
+        
+        # tk.Button(self, text="Open configuration file folder", command=lambda: controller.openConfigurationFileFolder(controller.homeDirectory)).pack(side=tk.BOTTOM)
+        # tk.Label(self, text="You can access the folder where configuration files are saved with this button.").pack(side=tk.RIGHT)
 
-        tk.Label(self, text="", font=controller.title_font).pack()
-        button3.pack()
-
-        tk.Label(self, text="", font=controller.title_font).pack()
-        button2.pack()
+        tk.Label(self, text="Welcome to ZebraZoom!", font=controller.title_font, pady=20).grid(row=0,column=0, columnspan = 2)
         
-        tk.Label(self, text="", font=controller.title_font).pack()
-        tk.Button(self, text="Open configuration file folder", command=lambda: controller.openConfigurationFileFolder(controller.homeDirectory)).pack()
+        tk.Label(self, text="1 - Create a Configuration File:", font = "bold", pady=10).grid(row=1,column=0)
+        tk.Button(self, text="Prepare configuration file for tracking", command=lambda: controller.show_frame("ChooseVideoToCreateConfigFileFor")).grid(row=2,column=0)
+        tk.Label(self, text="You first need to create a configuration file for each 'type' of video you want to track.", pady=10).grid(row=3,column=0)
+        tk.Button(self, text="Open configuration file folder", command=lambda: controller.openConfigurationFileFolder(controller.homeDirectory)).grid(row=4,column=0)
+        tk.Label(self, text="Access the folder where configuration files are saved with the button above.", pady=10).grid(row=5,column=0)
+        tk.Label(self, text="").grid(row=6,column=0)
         
-        tk.Label(self, text="", font=controller.title_font).pack()
-        tk.Button(self, text="Open ZebraZoom's output folder", command=lambda: controller.openZZOutputFolder(controller.homeDirectory)).pack()
+        tk.Label(self, text="2 - Run the Tracking:", font = "bold", pady=10).grid(row=1,column=1)
+        tk.Button(self, text="Run ZebraZoom's Tracking on a video", command=lambda: controller.show_frame("VideoToAnalyze")).grid(row=2,column=1)
+        tk.Label(self, text="Once you have a configuration file, use it to track a video.", pady=10).grid(row=3,column=1)
+        tk.Button(self, text="Run ZebraZoom's Tracking on several videos", command=lambda: controller.show_frame("SeveralVideos")).grid(row=4,column=1)
+        tk.Label(self, text="Or run the tracking on all videos inside a folder.", pady=10).grid(row=5,column=1)
         
-        tk.Label(self, text="", font=controller.title_font).pack()
-        tk.Button(self, text="Analyze ZebraZoom's outputs", command=lambda: controller.show_frame("CreateExperimentOrganizationExcel")).pack()
+        tk.Label(self, text="3 - Verify tracking results:", font = "bold", pady=10).grid(row=7,column=0)
+        tk.Button(self, text="Open ZebraZoom's output folder", command=lambda: controller.openZZOutputFolder(controller.homeDirectory)).grid(row=8,column=0)
+        tk.Label(self, text="Access the folder where the tracking results are saved with the button above.", pady=10).grid(row=9,column=0)
+        tk.Button(self, text="Visualize ZebraZoom's output", command=lambda: controller.showResultsVisualization()).grid(row=10,column=0)
+        tk.Label(self, text="Visualize/Verify/Explore the tracking results with the button above.", pady=10).grid(row=11,column=0)
         
-        tk.Label(self, text="", font=controller.title_font).pack()
-        tk.Button(self, text="Troubleshoot", command=lambda: controller.show_frame("ChooseVideoToTroubleshootSplitVideo")).pack()
+        tk.Label(self, text="4 - Analyze behavior:", font = "bold", pady=10).grid(row=7,column=1)
+        tk.Button(self, text="Analyze ZebraZoom's outputs", command=lambda: controller.show_frame("CreateExperimentOrganizationExcel")).grid(row=8,column=1)
+        tk.Label(self, text="Compare populations based on either kinematic parameters or clustering of bouts.", pady=10).grid(row=9,column=1)
+        
+        tk.Label(self, text="").grid(row=12,column=0, columnspan = 2)
+        tk.Button(self, text="Troubleshoot", command=lambda: controller.show_frame("ChooseVideoToTroubleshootSplitVideo")).grid(row=13,column=0, columnspan = 2)
+        
+        def callback(url):
+            webbrowser.open_new(url)
+        
+        link1 = tk.Button(self, text="Video online documentation")
+        link1.grid(row=14,column=0, columnspan = 2)
+        link1.bind("<Button-1>", lambda e: callback("https://github.com/oliviermirat/ZebraZoom#tableofcontent"))
         
 
 class SeveralVideos(tk.Frame):
@@ -287,49 +299,49 @@ class ViewParameters(tk.Frame):
               numMouv = nbMouv - 1
           
           label = tk.Label(self, text="    ", font=LARGE_FONT)
-          label.grid(row=0,column=6)
+          label.grid(row=1,column=6)
           
-          ttk.Button(self, text="View video for all wells together", command=lambda: controller.showValidationVideo(-1,0,-1)).grid(row=0,column=1)
+          ttk.Button(self, text="View video for all wells together", command=lambda: controller.showValidationVideo(-1,0,-1)).grid(row=1,column=1)
           
-          label = tk.Label(self, text=name, font=LARGE_FONT)
-          label.grid(row=0,column=2)
+          label = tk.Label(self, text=name, font="bold", justify=LEFT, pady=10)
+          label.grid(sticky=W, row=0, column=0, columnspan=8)
           
           label = tk.Label(self, text="Well number:")
-          label.grid(row=1,column=1)
+          label.grid(row=2,column=1)
           e1 = tk.Entry(self)
           e1.insert(0,numWell)
-          e1.grid(row=1,column=2)
-          tk.Button(self, text="-", command=lambda: controller.printSomeResults(int(e1.get())-1,e2.get(),e3.get())).grid(row=1,column=3)
-          tk.Button(self, text="+", command=lambda: controller.printSomeResults(int(e1.get())+1,e2.get(),e3.get())).grid(row=1,column=4)
+          e1.grid(row=2,column=2)
+          tk.Button(self, text="-", command=lambda: controller.printSomeResults(int(e1.get())-1,e2.get(),e3.get())).grid(row=2,column=3)
+          tk.Button(self, text="+", command=lambda: controller.printSomeResults(int(e1.get())+1,e2.get(),e3.get())).grid(row=2,column=4)
           
-          ttk.Button(self, text="View zoomed video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),1,-1)).grid(row=2,column=2)
+          ttk.Button(self, text="View zoomed video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),1,-1)).grid(row=3,column=2)
           
           def callback(url):
             webbrowser.open_new(url)
           
           link1 = tk.Button(self, text="Video viewing tips", cursor="hand2", bg = 'red')
-          link1.grid(row=2,column=4)
+          link1.grid(row=3,column=4)
           link1.bind("<Button-1>", lambda e: callback("https://zebrazoom.org/validationVideoReading.html"))
           
           label = tk.Label(self, text="Fish number:")
-          label.grid(row=3,column=1)
+          label.grid(row=4,column=1)
           e2 = tk.Entry(self)
           e2.insert(0,numPoiss)
-          e2.grid(row=3,column=2)
-          tk.Button(self, text="-", command=lambda: controller.printSomeResults(e1.get(),int(e2.get())-1,e3.get())).grid(row=3,column=3)
-          tk.Button(self, text="+", command=lambda: controller.printSomeResults(e1.get(),int(e2.get())+1,e3.get())).grid(row=3,column=4)
+          e2.grid(row=4,column=2)
+          tk.Button(self, text="-", command=lambda: controller.printSomeResults(e1.get(),int(e2.get())-1,e3.get())).grid(row=4,column=3)
+          tk.Button(self, text="+", command=lambda: controller.printSomeResults(e1.get(),int(e2.get())+1,e3.get())).grid(row=4,column=4)
           
           label = tk.Label(self, text="Bout number:")
-          label.grid(row=4,column=1)
+          label.grid(row=5,column=1)
           e3 = tk.Entry(self)
           e3.insert(0,numMouv)
-          e3.grid(row=4,column=2)
-          tk.Button(self, text="-", command=lambda: controller.printSomeResults(e1.get(),e2.get(),int(e3.get())-1)).grid(row=4,column=3)
-          tk.Button(self, text="+", command=lambda: controller.printSomeResults(e1.get(),e2.get(),int(e3.get())+1)).grid(row=4,column=4)
+          e3.grid(row=5,column=2)
+          tk.Button(self, text="-", command=lambda: controller.printSomeResults(e1.get(),e2.get(),int(e3.get())-1)).grid(row=5,column=3)
+          tk.Button(self, text="+", command=lambda: controller.printSomeResults(e1.get(),e2.get(),int(e3.get())+1)).grid(row=5,column=4)
           
           button1 = ttk.Button(self, text="View bout's angle",
                               command=lambda: controller.printSomeResults(e1.get(),e2.get(),e3.get()))
-          button1.grid(row=5,column=2)
+          button1.grid(row=6,column=2)
           
           
           if (len(dataRef["wellPoissMouv"][numWell][numPoiss]) > 0):
@@ -345,34 +357,34 @@ class ViewParameters(tk.Frame):
             button3 = tk.Button(self, text=flagTxt, command=lambda: controller.flagMove(e1.get(),e2.get(),e3.get()))
             if flagTxt == "UnFlag Movement":
               button3.configure(bg = 'red')
-            button3.grid(row=5,column=4)
+            button3.grid(row=6,column=4)
 
           
           prev = ttk.Button(self, text="Previous Bout",
                               command=lambda: controller.printPreviousResults(e1.get(),e2.get(),e3.get(), nbWells, nbPoiss, nbMouv))
-          prev.grid(row=6,column=1)
+          prev.grid(row=7,column=1)
           
           next = ttk.Button(self, text="Next Bout",
                               command=lambda: controller.printNextResults(e1.get(),e2.get(),e3.get(),nbWells,nbPoiss,nbMouv))
-          next.grid(row=6,column=2)
+          next.grid(row=7,column=2)
           
-          tk.Button(self, text="Go to the previous page", command=lambda: controller.show_frame("ResultsVisualization")).grid(row=7,column=1)
+          tk.Button(self, text="Go to the previous page", command=lambda: controller.show_frame("ResultsVisualization")).grid(row=8,column=1)
           
-          tk.Button(self, text="Change Visualization", command=lambda: controller.printSomeResults(e1.get(), e2.get(), e3.get(), True)).grid(row=7,column=2)
+          tk.Button(self, text="Change Visualization", command=lambda: controller.printSomeResults(e1.get(), e2.get(), e3.get(), True)).grid(row=8,column=2)
           
           if (controller.superstructmodified == 1):
             button1 = tk.Button(self, text="Save SuperStruct", command=lambda: controller.saveSuperStruct(e1.get(),e2.get(),e3.get()))
             button1.configure(bg = 'orange')
-            button1.grid(row=6,column=4)
+            button1.grid(row=7,column=4)
 
           if nbMouv > 0:
               
               begMove = dataRef["wellPoissMouv"][numWell][numPoiss][numMouv]["BoutStart"]
               endMove = dataRef["wellPoissMouv"][numWell][numPoiss][numMouv]["BoutEnd"]
               
-              ttk.Button(self, text="View video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),0,begMove)).grid(row=2,column=1)
+              ttk.Button(self, text="View video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),0,begMove)).grid(row=3,column=1)
               
-              ttk.Button(self, text="View bout's video", command=lambda: controller.showValidationVideo(e1.get(),1,begMove)).grid(row=5,column=1)
+              ttk.Button(self, text="View bout's video", command=lambda: controller.showValidationVideo(e1.get(),1,begMove)).grid(row=6,column=1)
               
               if controller.visualization == 0 and not("TailAngle_smoothed" in dataRef["wellPoissMouv"][numWell][numPoiss][numMouv]):
                   controller.visualization = 1
@@ -389,7 +401,7 @@ class ViewParameters(tk.Frame):
                 label = tk.Label(self, text="Tail Angle Raw for well "+str(numWell)+", fish "+str(numPoiss)+", bout "+str(numMouv)+"                             ", font=LARGE_FONT)
               else:
                 label = tk.Label(self, text="Body Coordinates for well "+str(numWell)+" , fish "+str(numPoiss)+" , bout "+str(numMouv), font=LARGE_FONT)
-              label.grid(row=0,column=7)
+              label.grid(row=1,column=7)
               
               if controller.visualization == 0:
                 
@@ -461,7 +473,7 @@ class ViewParameters(tk.Frame):
               
               canvas = FigureCanvasTkAgg(f, self)
               canvas.draw()
-              canvas.get_tk_widget().grid(row=1,column=7,rowspan=7)
+              canvas.get_tk_widget().grid(row=2,column=7,rowspan=7)
 
           else:
           
@@ -474,8 +486,8 @@ class ViewParameters(tk.Frame):
 
               canvas = FigureCanvasTkAgg(f, self)
               canvas.draw()
-              canvas.get_tk_widget().grid(row=1,column=7,rowspan=7)
+              canvas.get_tk_widget().grid(row=2,column=7,rowspan=7)
               
               canvas = Canvas(self)
               canvas.create_text(100,10, text="No bout detected for well "+str(numWell))
-              canvas.grid(row=1,column=7,rowspan=7)
\ No newline at end of file
+              canvas.grid(row=2,column=7,rowspan=7)
\ No newline at end of file
