@@ -8,6 +8,7 @@ from tkinter import *
 import json
 import cv2
 from zebrazoom.code.GUI.getCoordinates import findWellLeft, findWellRight, findHeadCenter, findBodyExtremity
+from zebrazoom.code.GUI.automaticallyFindOptimalParameters import automaticallyFindOptimalParameters
 import math
 from zebrazoom.code.findWells import findWells
 from zebrazoom.code.getHyperparameters import getHyperparametersSimple
@@ -55,12 +56,23 @@ def chooseVideoToCreateConfigFileFor(self, controller, reloadConfigFile):
     self.videoToCreateConfigFileFor = filedialog.askopenfilename(initialdir = os.path.expanduser("~"),title = "Select video to create config file for",filetypes = (("video","*.*"),("all files","*.*")))
   controller.show_frame("ChooseGeneralExperiment")
 
-def chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophilia, rodent, other):
+def chooseGeneralExperimentFirstStep(self, controller, freeZebra, headEmbZebra, drosophilia, rodent, other):
+  self.configFile["extractAdvanceZebraParameters"] = 0
+  if int(freeZebra):
+    controller.show_frame("FreelySwimmingExperiment")
+  else:
+    chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophilia, rodent, other, 0)
+
+def chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophilia, rodent, other, freeZebra2):
   self.configFile["extractAdvanceZebraParameters"] = 0
   if int(freeZebra):
     self.organism = 'zebrafish'
     self.configFile["headEmbeded"] = 0
     controller.show_frame("WellOrganisation")
+  elif int(freeZebra2):
+    self.organism = 'zebrafishNew'
+    self.configFile["headEmbeded"] = 0
+    controller.show_frame("WellOrganisation")
   elif int(headEmbZebra):
     self.organism = 'headembeddedzebrafish'
     self.configFile["headEmbeded"] = 1
@@ -295,12 +307,15 @@ def chooseBeginningAndEndOfVideo(self, controller):
   if int(self.configFile["headEmbeded"]) == 1:
     controller.show_frame("HeadEmbeded")
   else:
-    controller.show_frame("NumberOfAnimals")
+    if self.organism == 'zebrafishNew':
+      controller.show_frame("NumberOfAnimals2")
+    else:
+      controller.show_frame("NumberOfAnimals")
 
   
 def getImageForMultipleAnimalGUI(l, vertical, horizontal, nx, ny, max_l, videoToCreateConfigFileFor, background, wellPositions, hyperparameters):
   
-  frame = getForegroundImage(videoToCreateConfigFileFor, background, l, 0, [], hyperparameters)
+  [frame, a1, a2] = getForegroundImage(videoToCreateConfigFileFor, background, l, 0, [], hyperparameters)
   
   lengthX = nx * 2
   lengthY = ny
@@ -498,7 +513,7 @@ def identifyMultipleHead(self, controller, nbanimals):
   self.configFile["headSize"]        = math.sqrt((int(hyperparameters["minArea"]) + int(hyperparameters["maxArea"])) / 2)
 
 
-def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHeadTracking):
+def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHeadTracking, yesBouts, nooBouts, recommendedMethod, alternativeMethod):
 
   self.configFile["noBoutsDetection"] = 1
   self.configFile["noChecksForBoutSelectionInExtractParams"] = 1
@@ -521,6 +536,14 @@ def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHea
   
   if self.organism == 'zebrafish':
     controller.show_frame("IdentifyHeadCenter")
+  elif self.organism == 'zebrafishNew':
+    detectBouts = 0
+    if int(yesBouts):
+      detectBouts = 1
+    method = 0
+    if int(alternativeMethod):
+      method = 1
+    automaticallyFindOptimalParameters(self, controller, True, detectBouts, method)
   else:
     identifyMultipleHead(self, controller, nbanimals)
     controller.show_frame("FinishConfig")
