@@ -2,8 +2,9 @@ import numpy as np
 import cv2
 import math
 import json
-import popUpAlgoFollow
+import zebrazoom.code.popUpAlgoFollow as popUpAlgoFollow
 import random
+import os
 
 def createValidationVideo(videoPath, superStruct, hyperparameters):
 
@@ -19,6 +20,7 @@ def createValidationVideo(videoPath, superStruct, hyperparameters):
   frame_width  = int(cap.get(3))
   frame_height = int(cap.get(4))
   nbFrames     = int(cap.get(7))
+  inputFps     = int(cap.get(5))
   
   infoFrame = [[]] * nbFrames
   infoWells = []
@@ -31,7 +33,6 @@ def createValidationVideo(videoPath, superStruct, hyperparameters):
   for i in range(0, len(superStruct["wellPoissMouv"])):
     colorModifTab = [{"red": random.randrange(255), "green": random.randrange(255), "blue": random.randrange(255)} for i in range(1, hyperparameters["nbAnimalsPerWell"])]
     colorModifTab.insert(0, {"red": 0, "green": 0, "blue": 0})
-    # colorModifTab.insert(0, {"red": 0, "green": 0, "blue": 0})
     for j in range(0, len(superStruct["wellPoissMouv"][i])):
       for k in range(0, len(superStruct["wellPoissMouv"][i][j])):
       
@@ -62,6 +63,7 @@ def createValidationVideo(videoPath, superStruct, hyperparameters):
             dataToPlot["Heading"] = Heading
             dataToPlot["numMouv"] = k+1
             dataToPlot["numWell"] = i
+            dataToPlot["numAnimal"] = j
             
             dataToPlot["red"]     = 255
             dataToPlot["green"]   = 0
@@ -125,17 +127,61 @@ def createValidationVideo(videoPath, superStruct, hyperparameters):
               t2 = t.copy()
               t2.append(dataToPlot)
               infoFrame[BoutStart + l] = t2
-
+            
+            if hyperparameters["eyeTracking"]:
+              leftEyeX     = superStruct["wellPoissMouv"][i][j][k]["leftEyeX"][l]
+              leftEyeY     = superStruct["wellPoissMouv"][i][j][k]["leftEyeY"][l]
+              leftEyeAngle = superStruct["wellPoissMouv"][i][j][k]["leftEyeAngle"][l]
+              x = x + infoWells[i][0]
+              y = y + infoWells[i][1]
+              dataToPlot = {}
+              dataToPlot["x"]       = leftEyeX
+              dataToPlot["y"]       = leftEyeY
+              dataToPlot["size"]    = 1
+              dataToPlot["Heading"] = leftEyeAngle
+              dataToPlot["numMouv"] = k+1
+              dataToPlot["numWell"] = i
+              dataToPlot["red"]     = 255
+              dataToPlot["green"]   = 255
+              dataToPlot["blue"]    = 0
+              t = infoFrame[BoutStart + l]
+              t2 = t.copy()
+              t2.append(dataToPlot)
+              infoFrame[BoutStart + l] = t2
+              
+              rightEyeX     = superStruct["wellPoissMouv"][i][j][k]["rightEyeX"][l]
+              rightEyeY     = superStruct["wellPoissMouv"][i][j][k]["rightEyeY"][l]
+              rightEyeAngle = superStruct["wellPoissMouv"][i][j][k]["rightEyeAngle"][l]
+              x = x + infoWells[i][0]
+              y = y + infoWells[i][1]
+              dataToPlot = {}
+              dataToPlot["x"]       = rightEyeX
+              dataToPlot["y"]       = rightEyeY
+              dataToPlot["size"]    = 1
+              dataToPlot["Heading"] = rightEyeAngle
+              # dataToPlot["numMouv"] = k+1
+              # dataToPlot["numWell"] = i
+              dataToPlot["red"]     = 0
+              dataToPlot["green"]   = 0
+              dataToPlot["blue"]    = 255
+              t = infoFrame[BoutStart + l]
+              t2 = t.copy()
+              t2.append(dataToPlot)
+              infoFrame[BoutStart + l] = t2
+            
   # Going through the video and printing stuff on it.
-  outputName = hyperparameters["outputFolder"] + hyperparameters["videoName"] + '/' + hyperparameters["videoName"] + '.avi'
-  out = cv2.VideoWriter(outputName,cv2.VideoWriter_fourcc('M','J','P','G'), 10, (frame_width,frame_height))
+  outputName = os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), hyperparameters["videoName"] + '.avi')
+  outputFps = inputFps
+  if hyperparameters["outputValidationVideoFps"] > 0:
+    outputFps = int(hyperparameters["outputValidationVideoFps"])
+  
+  out = cv2.VideoWriter(outputName,cv2.VideoWriter_fourcc('M','J','P','G'), outputFps, (frame_width,frame_height))
 
   cap.set(1, firstFrame)
   
   for l in range(firstFrame, lastFrame):
   
     if l < nbFrames:
-      # cap.set(1, l)
       ret, frame = cap.read()
       
       for i in range(0, len(infoFrame[l])):
@@ -149,34 +195,26 @@ def createValidationVideo(videoPath, superStruct, hyperparameters):
           heading = infoFrame[l][i]["Heading"]
           if hyperparameters["validationVideoPlotHeading"]:
             if hyperparameters["debugValidationVideoHeading"] == 0:
-              cv2.line(frame,(int(x),int(y)),(int(x+20*math.cos(heading)),int(y+20*math.sin(heading))), (255,0,0), trackingPointSizeDisplay+1)
+              cv2.line(frame,(int(x),int(y)),(int(x+20*math.cos(heading)),int(y+20*math.sin(heading))), (255,0,0), trackingPointSizeDisplay)
             else:
-              cv2.line(frame,(int(x),int(y)),(int(x-250*math.cos(heading)),int(y-250*math.sin(heading))), (255,0,0), trackingPointSizeDisplay+1)
+              cv2.line(frame,(int(x),int(y)),(int(x-250*math.cos(heading)),int(y-250*math.sin(heading))), (255,0,0), trackingPointSizeDisplay)
           
-          font = cv2.FONT_HERSHEY_SIMPLEX
-          numMouv = infoFrame[l][i]["numMouv"]
-          numWell = infoFrame[l][i]["numWell"]
-          cv2.putText(frame,str(numMouv),(15+infoWells[numWell][0],25+infoWells[numWell][1]),font,1,(255,255,255))
-          
-          # CvFont font;
-          # cvInitFont( &font, CV_FONT_HERSHEY_SIMPLEX,0.7,0.7,0,2,8);
-          # std::ostringstream out;
-          # out << infoFrame[l][i]["numMouv"];
-          # string str = out.str();
-          # size_t size = str.size() + 1;
-          # char * buffer = new char[ size ];
-          # strncpy( buffer, str.c_str(), size );
-          # int numWell = (int) infoFrame[l][i]["numWell"];
-          # cvRectangle(dst,cvPoint((int)infoWells[numWell][0],(int)infoWells[numWell][1]),cvPoint(15 + (int)infoWells[numWell][0], 25 + (int)infoWells[numWell][1]),CV_RGB(0,0,255),-1);
-          # cvPutText(dst,buffer,cvPoint((int)infoWells[numWell][0],20+(int)infoWells[numWell][1]),&font,CV_RGB(255,255,255));
+          if ("numMouv" in infoFrame[l][i]) and ("numWell" in infoFrame[l][i]):
+            numMouv = infoFrame[l][i]["numMouv"]
+            numWell = infoFrame[l][i]["numWell"]
+            cv2.putText(frame,str(numMouv),(15+infoWells[numWell][0],25+infoWells[numWell][1]),cv2.FONT_HERSHEY_SIMPLEX,1,(255,255,255))
 
         cv2.circle(frame, (int(x),int(y)), size, (red,green,blue), -1)
         
-      # cv2.imshow('Frame', frame)
-      # cv2.waitKey(10)
+        if hyperparameters["validationVideoPlotAnimalNumber"]:
+          if "numAnimal" in infoFrame[l][i]:
+            numAnimal = int(infoFrame[l][i]["numAnimal"])
+            red       = int(0   + colorModifTab[numAnimal]["red"])
+            green     = int(255 - colorModifTab[numAnimal]["green"])
+            blue      = int(0   + colorModifTab[numAnimal]["blue"])
+            cv2.putText(frame, str(numAnimal), (int(x + 10), int(y + 10)), cv2.FONT_HERSHEY_SIMPLEX, 1, (red, green, blue), 2)
+        
       out.write(frame)
-      
-      # l = l + 1
   
   out.release()
   
