@@ -298,6 +298,9 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["imagePreProcessMethod"] = getConfig(config, "imagePreProcessMethod", videoPath)
   hyperparameters["imagePreProcessParameters"] = getConfig(config, "imagePreProcessParameters", videoPath)
   
+  hyperparameters["backgroundPreProcessMethod"] = getConfig(config, "backgroundPreProcessMethod", videoPath)
+  hyperparameters["backgroundPreProcessParameters"] = getConfig(config, "backgroundPreProcessParameters", videoPath)
+  
   hyperparameters["backgroundExtractionWithOnlyTwoFrames"] = getConfig(config, "backgroundExtractionWithOnlyTwoFrames", videoPath)
   
   hyperparameters["checkThatMovementOccurInVideo"] = getConfig(config, "checkThatMovementOccurInVideo", videoPath)
@@ -333,6 +336,15 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["computeEyesHeadingPlot"]             = getConfig(config, "computeEyesHeadingPlot", videoPath)
   hyperparameters["adjustMinPixelDiffForBackExtract_nbBlackPixelsMax"] = getConfig(config, "adjustMinPixelDiffForBackExtract_nbBlackPixelsMax", videoPath)
   
+  hyperparameters["fixedHeadPositionX"] = getConfig(config, "fixedHeadPositionX", videoPath)
+  hyperparameters["fixedHeadPositionY"] = getConfig(config, "fixedHeadPositionY", videoPath)
+  
+  hyperparameters["recalculateForegroundImageBasedOnBodyArea"] = getConfig(config, "recalculateForegroundImageBasedOnBodyArea", videoPath)
+  
+  hyperparameters["detectMouthInsteadOfHeadTwoSides"] = getConfig(config, "detectMouthInsteadOfHeadTwoSides", videoPath)
+  hyperparameters["findCenterOfAnimalByIterativelyDilating"] = getConfig(config, "findCenterOfAnimalByIterativelyDilating", videoPath)
+  
+  hyperparameters["backgroundExtractionForceUseAllVideoFrames"] = getConfig(config, "backgroundExtractionForceUseAllVideoFrames", videoPath)
   
   if len(argv) > 5 and not(argv[0] == "getTailExtremityFirstFrame"):
     i = 5
