@@ -23,7 +23,7 @@ from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtre
 # from trackingFunctions import assignValueIfBetweenRange
 
  
-def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugAdv,heading, hyperparameters):
+def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugAdv,heading, hyperparameters, initialCurFrame, back):
   
   dst = frame.copy()
   dst = cv2.cvtColor(dst, cv2.COLOR_GRAY2RGB)
@@ -38,18 +38,14 @@ def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugA
     cv2.waitKey(0)
   
   # Finding blob corresponding to the body of the fish
-  bodyContour = findBodyContour(headPosition, hyperparameters, thresh1)
-  
+  bodyContour = findBodyContour(headPosition, hyperparameters, thresh1, initialCurFrame, back)
   if type(bodyContour) != int:
-    
     # Finding the two sides of the fish
-    res = findTheTwoSides(headPosition, bodyContour, dst)
-    
+    res = findTheTwoSides(headPosition, bodyContour, dst, hyperparameters)
     # Finding tail extremity
     rotatedContour = bodyContour.copy()
     rotatedContour = Rotate(rotatedContour,int(headPosition[0]),int(headPosition[1]),heading,dst)
     [MostCurvyIndex, distance2] = findTailExtremete(rotatedContour, bodyContour, headPosition[0], int(res[0]), int(res[1]), debugAdv, dst, hyperparameters["tailExtremityMaxJugeDecreaseCoeff"], hyperparameters)
-    
     if debugAdv:
       # Head Center
       cv2.circle(dst, (int(headPosition[0]),int(headPosition[1])), 3, (255, 255, 0), -1)
@@ -70,24 +66,48 @@ def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugA
       cv2.waitKey(0)
     
     # Getting Midline
-    taille = nbTailPoints
-    tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
+    if hyperparameters["detectMouthInsteadOfHeadTwoSides"] == 0:
+      tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, nbTailPoints-1, distance2, debugAdv, hyperparameters, nbTailPoints)
+    else:
+      tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, nbTailPoints+1, distance2, debugAdv, hyperparameters, nbTailPoints)
+      tail = np.array([tail[0][1:len(tail[0])]])
+    
+    if False:
+      maxDistContourToTail = -1
+      for contourPt in bodyContour:
+        contourPtX = contourPt[0][0]
+        contourPtY = contourPt[0][1]
+        minDistContourPointToTail = 1000000000000
+        for tailPt in np.append(tail[0], np.array([headPosition]), axis=0):
+          tailPtX = tailPt[0]
+          tailPtY = tailPt[1]
+          dist = math.sqrt((tailPtX - contourPtX)**2 + (tailPtY - contourPtY)**2)
+          if dist < minDistContourPointToTail:
+            minDistContourPointToTail = dist
+        if minDistContourPointToTail > maxDistContourToTail:
+          maxDistContourToTail = minDistContourPointToTail
+      print("maxDistContourToTail:", maxDistContourToTail, "; tailLength:", hyperparameters["minTailSize"]*10)
+      
+    if False:
+      for pt in bodyContour:
+        cv2.circle(dst, (pt[0][0], pt[0][1]), 3, (0, 0, 255), -1)
+      cv2.imshow('Frame', dst)
+      cv2.waitKey(0)
     
     # Optimizing midline if necessary
     midlineIsInBlobTrackingOptimization = hyperparameters["midlineIsInBlobTrackingOptimization"]
     if midlineIsInBlobTrackingOptimization:
-      [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
+      [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, nbTailPoints-1, distance2, debugAdv, hyperparameters, nbTailPoints)
       if allInside == False:
         n = len(bodyContour)
         maxTailLength = -1
         for j in range(0, n):
-          [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), j, bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
+          [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), j, bodyContour, dst, nbTailPoints-1, distance2, debugAdv, hyperparameters, nbTailPoints)
           if allInside:
             if tailLength > maxTailLength:
               MostCurvyIndex = j
               maxTailLength = tailLength
-        tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
-    
+        tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, nbTailPoints-1, distance2, debugAdv, hyperparameters, nbTailPoints)
     # Applying snake on tail
     applySnake = False
     if applySnake:
@@ -114,15 +134,28 @@ def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugA
   else:
     
     tail = np.zeros((1, 0, 2))
+    point = np.array([0, 0])
+    for i in range(0, nbTailPoints):
+      tail = np.insert(tail, 0, point, axis=1)  
+    if hyperparameters["detectMouthInsteadOfHeadTwoSides"] != 0:
+      tail = np.insert(tail, 0, point, axis=1)  
   
   # Inserting head position, smoothing tail and creating output
-  tail = np.insert(tail, 0, headPosition, axis=1)
+  if hyperparameters["detectMouthInsteadOfHeadTwoSides"] == 0:
+    tail = np.insert(tail, 0, headPosition, axis=1)
   # tail = smoothTail(tail, nbTailPoints)
+ 
+  if nbTailPoints != len(tail[0]):
+    print("small problem 1 in tailTrackingExtremityDetect")
   
-  output = np.zeros((1, len(tail[0]), 2))
+  # output = np.zeros((1, len(tail[0]), 2))
+  output = np.zeros((1, nbTailPoints, 2))
   
   for idx, x in enumerate(tail[0]):
-    output[0][idx][0] = x[0]
-    output[0][idx][1] = x[1]
+    if idx < nbTailPoints:
+      output[0][idx][0] = x[0]
+      output[0][idx][1] = x[1]
+    else:
+      print("small problem 2 in tailTrackingExtremityDetect")
 
   return output
