@@ -1,15 +1,11 @@
-import sys
-sys.path.insert(1, './datasetcreation/')
-sys.path.insert(1, './dataanalysis/')
-from createDataFrame import createDataFrame
-from populationComparaison import populationComparaison
+import zebrazoom
 
 # Creating the dataframe
 
 dataframeOptions = {
   'pathToExcelFile'                   : './experimentOrganizationExcel/',
   'fileExtension'                     : '.xls',
-  'resFolder'                         : './data/',
+  'resFolder'                         : 'data',
   'nameOfFile'                        : 'example',
   'smoothingFactorDynaParam'          : 0,   # 0.001
   'nbFramesTakenIntoAccount'          : 28,
@@ -20,7 +16,7 @@ dataframeOptions = {
   'computeMassCenterParamForCluster'  : False
 }
 
-[conditions, genotypes, nbFramesTakenIntoAccount] = createDataFrame(dataframeOptions)
+[conditions, genotypes, nbFramesTakenIntoAccount] = zebrazoom.createDataFrame(dataframeOptions)
 
 
 # Plotting for the different conditions
@@ -28,5 +24,5 @@ nameOfFile = dataframeOptions['nameOfFile']
 resFolder  = dataframeOptions['resFolder']
 globParam = ['BoutDuration', 'TotalDistance', 'Speed', 'NumberOfOscillations', 'meanTBF', 'maxAmplitude']
 
-populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, 'resultsKinematic/')
+zebrazoom.populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, 'resultsKinematic')
 
